#
# spec file for package gleam
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gleam
Version:        1.5.1
Release:        1.1
Summary:        A friendly language for building type-safe, scalable systems!
License:        Apache-2.0
URL:            https://gleam.run/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
# Due to Gleam Language Server using this feature:
# https://blog.rust-lang.org/2024/06/13/Rust-1.79.0.html#extending-automatic-temporary-lifetime-extension
BuildRequires:  cargo >= 1.79.0
# For tests
BuildRequires:  git-core
Requires:       erlang
Requires:       erlang-rebar3
ExclusiveArch:  %{rust_tier1_arches}

%description
The power of a type system, the expressiveness of functional programming,
and the reliability of the highly concurrent, fault tolerant Erlang runtime,
with a familiar and modern syntax.

%prep
%autosetup -p1 -a1

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/gleam %{buildroot}%{_bindir}/gleam

%check
%{cargo_test}

%files
%license LICENCE
%{_bindir}/%{name}

%changelog
* Thu Sep 26 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.5.1:
  * Fixed a bug where Erlang file paths would not be escaped on Windows.
  (Louis Pilfold)
* Thu Sep 19 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.5.0:
  * Changelog: https://gleam.run/news/convenient-code-actions/
* Fri Aug  2 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.4.0:
  * Changelog: https://gleam.run/news/supercharged-labels/
  * Gleam now requires Rust 1.79 to build
* Thu Jul 11 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.3.2:
  Language Server
  * The language server no longer shows completions when inside a literal string.
    (Giacomo Cavalieri)
  Bug Fixes
  * Fixed a bug where the compiler would report errors for duplicate `@external`
    attributes with inconsistent spans between Erlang and JavaScript.
    (Connor Szczepaniak)
  * Fixed a bug where `gleam add` would fail to parse version specifiers
    correctly.
    (Louis Pilfold)
  * Fixed a bug where single clause case expressions could generate JavaScript
    code with incorrectly rewritten JavaScript variable names.
    (Louis Pilfold)
* Wed Jul 10 2024 Pi-Cla <pirateclip@protonmail.com>
- Update to 1.3.1:
  * Fixes a bug with import cycle detection when there is more than 2 imports in the cycle
  (Ameen Radwan)
* Tue Jul  9 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.3.0:
  * Changelog: https://gleam.run/news/auto-imports-and-tolerant-expressions/
* Thu May 30 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.2.1:
  * Fixed a bug where the compiler could fail to detect modules that
  would clash with Erlang modules. (Louis Pilfold)
  * Fixed a bug where dependency version resolution could crash for
  certain release candidate versions. (Marshall Bowers)
  * Fixed a bug where trailing comments would be moved out of a bit
  array. (Giacomo Cavalieri)
* Mon May 27 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 1.2.0:
  * Changelog: https://gleam.run/news/fault-tolerant-gleam/
* Tue Apr  9 2024 Gordon Leung <pirateclip@protonmail.com>
- Initial commit
